==> open-xchange-appsuite_7.8.3.orig.tar.bz2: open-xchange-appsuite-7.8.3/ui/apps/io.ox/mail/settings/defaults.js <==
/**
 * This work is provided under the terms of the CREATIVE COMMONS PUBLIC
 * LICENSE. This work is protected by copyright and/or other applicable
 * law. Any use of the work other than as authorized under this license
 * or copyright law is prohibited.
 *
 * http://creativecommons.org/licenses/by-nc-sa/2.5/
 *
 * © 2016 OX Software GmbH, Germany. info@open-xchange.com
 *
 * @author Christoph Kopp <christoph.kopp@open-xchange.com>
 */

define('io.ox/mail/settings/defaults', [], function () {

    'use strict';

    var settingsDefaults = {
        'removeDeletedPermanently': false,
        'contactCollectOnMailTransport': false,
        'contactCollectOnMailAccess': false,
        'useFixedWidthFont': false,
        'appendVcard': false,
        'sendDispositionNotification': false,
        'appendMailTextOnReply': true,
        'forwardMessageAs': 'Inline',
        'messageFormat': 'html',
        'lineWrapAfter': '0',
        'defaultSendAddress': '',
        'autoSaveDraftsAfter': 'disabled',
        'allowHtmlMessages': true,
        'allowHtmlImages': false,
        'displayEmoticons': false,
        'isColorQuoted': false,
        'defaultSignature': false,
        'defaultReplyForwardSignature': false,
        'mobileSignature': undefined,
        // one of 'none', 'custom'
        'mobileSignatureType': 'none',
        'threadSupport': true,
        //for persistent sort
        'sort': 'thread',
        'order': 'desc',
        'unread': false,
        'simpleLineBreaks': true,
        'notificationSoundName': 'bell',
        'playSound': true
    };

    return settingsDefaults;
});

==> open-xchange-appsuite_7.8.4.orig.tar.bz2: open-xchange-appsuite-7.8.4/ui/apps/io.ox/mail/settings/defaults.js <==
/**
 * This work is provided under the terms of the CREATIVE COMMONS PUBLIC
 * LICENSE. This work is protected by copyright and/or other applicable
 * law. Any use of the work other than as authorized under this license
 * or copyright law is prohibited.
 *
 * http://creativecommons.org/licenses/by-nc-sa/2.5/
 *
 * © 2016 OX Software GmbH, Germany. info@open-xchange.com
 *
 * @author Christoph Kopp <christoph.kopp@open-xchange.com>
 */

define('io.ox/mail/settings/defaults', [], function () {

    'use strict';

    var settingsDefaults = {
        'removeDeletedPermanently': false,
        'contactCollectOnMailTransport': false,
        'contactCollectOnMailAccess': false,
        'useFixedWidthFont': false,
        'appendVcard': false,
        'sendDispositionNotification': false,
        'appendMailTextOnReply': true,
        'forwardMessageAs': 'Inline',
        'messageFormat': 'html',
        'lineWrapAfter': '0',
        'defaultSendAddress': '',
        'autoSaveDraftsAfter': 'disabled',
        'allowHtmlMessages': true,
        'allowHtmlImages': false,
        'displayEmoticons': false,
        'isColorQuoted': false,
        'beautifyPlainText': false,
        'defaultSignature': false,
        'defaultReplyForwardSignature': false,
        'mobileSignature': undefined,
        // one of 'none', 'custom'
        'mobileSignatureType': 'none',
        'threadSupport': true,
        //for persistent sort
        'sort': 'thread',
        'order': 'desc',
        'unread': false,
        'simpleLineBreaks': true,
        'notificationSoundName': 'bell',
        'playSound': true,
        'confirmReplyToMailingLists': true,
        'unseenMessagesFolder': true,
        'showCheckboxes': true  // show checkboxes in mail list as default
    };

    return settingsDefaults;
});
